@@ -1,4 +1,4 @@
-# Copyright 2019-2022 SURF.
+# Copyright 2019-2023 SURF.
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -217,9 +217,12 @@ class OIDCUser(HTTPBearer):
             if token:
                 user_info = await self.introspect_token(async_request, token)
 
+                if "active" not in user_info:
+                    logger.error("Token doesn't have the mandatory 'active' key, probably caused by a caching problem")
+                    raise HTTPException(status_code=HTTPStatus.UNAUTHORIZED, detail="Missing active key")
                 if not user_info.get("active", False):
-                    logger.debug("Token is invalid", url=request.url, user_info=user_info)
-                    raise HTTPException(status_code=HTTPStatus.UNAUTHORIZED, detail="Access token is invalid")
+                    logger.error("User is not active", url=request.url, user_info=user_info)
+                    raise HTTPException(status_code=HTTPStatus.UNAUTHORIZED, detail="User is not active")
 
                 logger.debug("OIDCUserModel object.", user_info=user_info)
                 return user_info
@@ -364,3 +367,70 @@ def opa_decision(
         return None
 
     return _opa_decision
+
+
+def opa_graphql_decision(
+    opa_url: str,
+    _oidc_security: OIDCUser,
+    enabled: bool = True,
+    auto_error: bool = True,
+    opa_kwargs: Mapping[str, str] | None = None,
+) -> Callable[[str, OIDCUserModel], Coroutine[Any, Any, bool | None]]:
+    async def _opa_decision(
+        path: str,
+        oidc_user: OIDCUserModel,
+    ) -> bool | None:
+        """
+        Check OIDCUserModel against the OPA policy.
+
+        This is used as a security module in Graphql projects
+        This method will make an async call towards the Policy agent.
+
+        Args:
+            path: the graphql path that will be checked against the permissions of the oidc_user
+            oidc_user: The OIDCUserModel object that will be checked
+        """
+        if enabled:
+            opa_input = {
+                "input": {
+                    **(opa_kwargs or {}),
+                    **oidc_user,
+                    "resource": path,
+                    "method": "POST",
+                }
+            }
+
+            logger.debug("Posting input json to Policy agent", input=opa_input)
+
+            try:
+                result = await AsyncClient(http1=True).post(opa_url, json=opa_input)
+            except (NetworkError, TypeError):
+                raise HTTPException(status_code=HTTPStatus.SERVICE_UNAVAILABLE, detail="Policy agent is unavailable")
+
+            data = OPAResult.parse_obj(result.json())
+
+            resource = opa_input["input"]["resource"]
+
+            if not data.result and auto_error:
+                logger.debug(
+                    "User is not allowed to access the resource",
+                    decision_id=data.decision_id,
+                    path=path,
+                    input=opa_input,
+                )
+                return False
+            else:
+                if data.result:
+                    logger.debug(
+                        "User is authorized to access the resource",
+                        decision_id=data.decision_id,
+                        resource=resource,
+                        path=path,
+                        input=opa_input,
+                    )
+
+                return data.result
+
+        return None
+
+    return _opa_decision
